@@ -24,18 +24,18 @@ import getpass
 import logging
 import logging.handlers
 
+import debian.debian_support
+
 # Workaround: Avoid warning 'No handlers could be found for logger "keyring"'
 KEYRING_LOG = logging.getLogger("keyring")
 KEYRING_LOG.addHandler(logging.NullHandler())
-import keyring
-# pylint: disable=F0401,E0611
+import keyring  # pylint: disable=wrong-import-position
 try:
-    from keyring.util.platform_ import data_root as keyring_data_root
+    from keyring.util.platform_ import data_root as keyring_data_root  # pylint: disable=wrong-import-position,wrong-import-order,import-error,no-name-in-module
 except ImportError:
-    from keyring.util.platform import data_root as keyring_data_root
-# pylint: enable=F0401,E0611
+    from keyring.util.platform import data_root as keyring_data_root  # pylint: disable=wrong-import-position,wrong-import-order,import-error,no-name-in-module
 
-import mini_buildd.setup
+import mini_buildd.setup  # pylint: disable=wrong-import-position
 
 LOG = logging.getLogger(__name__)
 
@@ -364,6 +364,18 @@ def guess_codeversion(release):
         return release["Codename"].upper()
 
 
+def guess_default_dirchroot_backend(overlay, aufs):
+    try:
+        release = os.uname()[2]
+        # linux 3.18-1~exp1 in Debian removed aufs in favor of overlay
+        if debian.debian_support.Version(release) < debian.debian_support.Version("3.18"):
+            return aufs
+    except:
+        pass
+
+    return overlay
+
+
 def pkg_fmt(status, distribution, package, version, extra=None, message=None):
     "Generate a package status line."
     fmt = "{status} ({distribution}): {package} {version}".format(status=status,
@@ -511,6 +523,9 @@ def list_get(list_, index, default=None):
 
 
 def mkdirs(path):
+    """
+    .. note:: Needed for python 2.x only. For 3.x, just use 'exist_ok' parameter.
+    """
     try:
         os.makedirs(path)
         LOG.info("Directory created: {d}".format(d=path))
@@ -755,6 +770,17 @@ Save password for '{k}': (Y)es, (N)o, (A)lways, Ne(v)er? """.format(c=self, k=ke
         return key, user, password, new
 
 
+def canonize_url(url):
+    "Poor man's URL canonizer: Always include the port (currently only works for 'http' and 'https' default ports)."
+    default_scheme2port = {"http": ":80", "https": ":443"}
+
+    parsed = urlparse.urlparse(url)
+    netloc = parsed.netloc
+    if parsed.port is None:
+        netloc = parsed.hostname + default_scheme2port.get(parsed.scheme, "")
+    return urlparse.urlunsplit((parsed.scheme, netloc, parsed.path, parsed.query, ""))
+
+
 def web_login(host, user, credentials,
               proto="http",
               login_loc="/accounts/login/",
@@ -775,7 +801,7 @@ def web_login(host, user, credentials,
         # Find "csrftoken" in cookiejar
         csrf_cookies = [c for c in cookie_handler.cookiejar if c.name == "csrftoken"]
         if len(csrf_cookies) != 1:
-            raise Exception("{n} csrftoken cookies found in login pages (need exactly 1).")
+            raise Exception("{n} csrftoken cookies found in login pages (need exactly 1).".format(n=len(csrf_cookies)))
         LOG.debug("csrftoken={c}".format(c=csrf_cookies[0].value))
 
         # Login via POST request
@@ -786,10 +812,10 @@ def web_login(host, user, credentials,
                               "csrfmiddlewaretoken": csrf_cookies[0].value,
                               "this_is_the_login_form": "1",
                               "next": next_loc,
-                              }))
+                             }))
 
         # If successful, next url of the response must match
-        if response.geturl() != next_url:
+        if canonize_url(response.geturl()) != canonize_url(next_url):
             raise Exception("Wrong credentials: Please try again")
 
         # Logged in: Install opener, save credentials
@@ -841,9 +867,3 @@ def setup_console_logging(level=logging.DEBUG):
         l = logging.getLogger(ln)
         l.addHandler(ch)
         l.setLevel(level)
-
-
-if __name__ == "__main__":
-    setup_console_logging()
-    import doctest
-    doctest.testmod()
