@@ -57,7 +57,7 @@ go to the default mapping.
         ordering = ["source", "architecture"]
 
     class Admin(mini_buildd.models.base.StatusModel.Admin):
-        search_fields = ["source", "architecture"]
+        search_fields = ["source__codename", "architecture__name"]
         readonly_fields = ["personality"]
         fieldsets = [
             ("Chroot identity", {"fields": (("source", "architecture"), "personality", "personality_override")}),
@@ -104,8 +104,8 @@ chroots (with <tt>qemu-user-static</tt> installed).
                         if s.codename in ["lenny", "etch"]:
                             extra_options = "Debootstrap-Command: /usr/sbin/mbd-debootstrap-uname-2.6\n"
                         chroot_model.mbd_get_or_create(msglog, source=s, architecture=a, extra_options=extra_options)
-                    except:
-                        msglog.info("Another backend already provides {s}/{a}".format(s=s.codename, a=a.name))
+                    except Exception as e:
+                        msglog.warn("{s}/{a}: Skipping customized chroot (on another backend, or not on default values) [{e}]".format(s=s.codename, a=a.name, e=e))
 
     def __unicode__(self):
         return "{o} '{c}:{a}' ({f})".format(o=self.source.origin,
@@ -151,17 +151,16 @@ chroots (with <tt>qemu-user-static</tt> installed).
         return [
             (["/bin/mkdir", "--verbose", self.mbd_get_tmp_dir()],
              ["/bin/rm", "--recursive", "--one-file-system", "--force", self.mbd_get_tmp_dir()])] + self.mbd_get_backend().mbd_get_pre_sequence() + [
-            ([self.mbd_get_extra_option("Debootstrap-Command", "/usr/sbin/debootstrap"),
-              "--variant=buildd",
-              "--keyring={k}".format(k=self.mbd_get_keyring_file()),
-              "--arch={a}".format(a=self.architecture.name),
-              self.source.codename,
-              self.mbd_get_tmp_dir(),
-              self.source.mbd_get_archive().url],
-             ["/bin/umount", "-v", os.path.join(self.mbd_get_tmp_dir(), "proc"), os.path.join(self.mbd_get_tmp_dir(), "sys")])] + self.mbd_get_backend().mbd_get_post_sequence() + [
-
-            (["/bin/cp", "--verbose", self.mbd_get_schroot_conf_file(), self.mbd_get_system_schroot_conf_file()],
-             ["/bin/rm", "--verbose", self.mbd_get_system_schroot_conf_file()])]
+                 ([self.mbd_get_extra_option("Debootstrap-Command", "/usr/sbin/debootstrap"),
+                   "--variant=buildd",
+                   "--keyring={k}".format(k=self.mbd_get_keyring_file()),
+                   "--arch={a}".format(a=self.architecture.name),
+                   self.source.codename,
+                   self.mbd_get_tmp_dir(),
+                   self.source.mbd_get_archive().url],
+                  ["/bin/umount", "-v", os.path.join(self.mbd_get_tmp_dir(), "proc"), os.path.join(self.mbd_get_tmp_dir(), "sys")])] + self.mbd_get_backend().mbd_get_post_sequence() + [
+                      (["/bin/cp", "--verbose", self.mbd_get_schroot_conf_file(), self.mbd_get_system_schroot_conf_file()],
+                       ["/bin/rm", "--verbose", self.mbd_get_system_schroot_conf_file()])]
 
     def mbd_prepare(self, request):
         mini_buildd.misc.mkdirs(os.path.join(self.mbd_get_path(), mini_buildd.setup.CHROOT_LIBDIR))
@@ -290,7 +289,8 @@ class DirChroot(Chroot):
         (UNION_OVERLAYFS, "overlayfs"),
         (UNION_UNIONFS, "unionfs"),
         (UNION_OVERLAY, "overlay"))
-    union_type = django.db.models.IntegerField(choices=UNION_CHOICES, default=UNION_OVERLAY,
+    union_type = django.db.models.IntegerField(choices=UNION_CHOICES,
+                                               default=mini_buildd.misc.guess_default_dirchroot_backend(overlay=UNION_OVERLAY, aufs=UNION_AUFS),
                                                help_text="""\
 See 'man 5 schroot.conf'
 """)
